@@ -10,8 +10,8 @@ import (
 	"unicode"
 
 	"github.com/zyedidia/json5"
-	"github.com/zyedidia/micro/internal/config"
-	"github.com/zyedidia/micro/internal/screen"
+	"github.com/zyedidia/micro/v2/internal/config"
+	"github.com/zyedidia/micro/v2/internal/screen"
 	"github.com/zyedidia/tcell"
 )
 
@@ -249,6 +249,7 @@ func UnbindKey(k string) error {
 		if a, ok := defaults[k]; ok {
 			BindKey(k, a)
 		} else if _, ok := config.Bindings[k]; ok {
+			BufUnmap(key)
 			delete(config.Bindings, k)
 		}
 
