@@ -32,26 +32,27 @@ func DefaultBindings() map[string]string {
 		"Enter":          "InsertNewline",
 		"CtrlH":          "Backspace",
 		"Backspace":      "Backspace",
+		"OldBackspace":   "Backspace",
 		"Alt-CtrlH":      "DeleteWordLeft",
 		"Alt-Backspace":  "DeleteWordLeft",
 		"Tab":            "Autocomplete|IndentSelection|InsertTab",
 		"Backtab":        "CycleAutocompleteBack|OutdentSelection|OutdentLine",
-		"CtrlO":          "OpenFile",
-		"CtrlS":          "Save",
-		"CtrlF":          "Find",
-		"CtrlN":          "FindNext",
-		"CtrlP":          "FindPrevious",
-		"CtrlZ":          "Undo",
-		"CtrlY":          "Redo",
-		"CtrlC":          "CopyLine|Copy",
-		"CtrlX":          "Cut",
-		"CtrlK":          "CutLine",
-		"CtrlD":          "DuplicateLine",
-		"CtrlV":          "Paste",
-		"CtrlA":          "SelectAll",
-		"CtrlT":          "AddTab",
-		"Alt,":           "PreviousTab",
-		"Alt.":           "NextTab",
+		"Ctrl-o":         "OpenFile",
+		"Ctrl-s":         "Save",
+		"Ctrl-f":         "Find",
+		"Ctrl-n":         "FindNext",
+		"Ctrl-p":         "FindPrevious",
+		"Ctrl-z":         "Undo",
+		"Ctrl-y":         "Redo",
+		"Ctrl-c":         "CopyLine|Copy",
+		"Ctrl-x":         "Cut",
+		"Ctrl-k":         "CutLine",
+		"Ctrl-d":         "DuplicateLine",
+		"Ctrl-v":         "Paste",
+		"Ctrl-a":         "SelectAll",
+		"Ctrl-t":         "AddTab",
+		"Alt-,":          "PreviousTab",
+		"Alt-.":          "NextTab",
 		"Home":           "StartOfTextToggle",
 		"End":            "EndOfLine",
 		"CtrlHome":       "CursorStart",
@@ -60,17 +61,17 @@ func DefaultBindings() map[string]string {
 		"PageDown":       "CursorPageDown",
 		"CtrlPageUp":     "PreviousTab",
 		"CtrlPageDown":   "NextTab",
-		"CtrlG":          "ToggleHelp",
+		"Ctrl-g":         "ToggleHelp",
 		"Alt-g":          "ToggleKeyMenu",
-		"CtrlR":          "ToggleRuler",
-		"CtrlL":          "command-edit:goto ",
+		"Ctrl-r":         "ToggleRuler",
+		"Ctrl-l":         "command-edit:goto ",
 		"Delete":         "Delete",
-		"CtrlB":          "ShellMode",
-		"CtrlQ":          "Quit",
-		"CtrlE":          "CommandMode",
-		"CtrlW":          "NextSplit",
-		"CtrlU":          "ToggleMacro",
-		"CtrlJ":          "PlayMacro",
+		"Ctrl-b":         "ShellMode",
+		"Ctrl-q":         "Quit",
+		"Ctrl-e":         "CommandMode",
+		"Ctrl-w":         "NextSplit",
+		"Ctrl-u":         "ToggleMacro",
+		"Ctrl-j":         "PlayMacro",
 		"Insert":         "ToggleOverwriteMode",
 
 		// Emacs-style keybindings
