@@ -87,6 +87,8 @@ func NewLineArray(size uint64, endings FileFormat, reader io.Reader) *LineArray
 	br := bufio.NewReader(reader)
 	var loaded int
 
+	la.Endings = endings
+
 	n := 0
 	for {
 		data, err := br.ReadBytes('\n')
@@ -189,10 +191,15 @@ func (la *LineArray) newlineBelow(y int) {
 func (la *LineArray) insert(pos Loc, value []byte) {
 	x, y := runeToByteIndex(pos.X, la.lines[pos.Y].data), pos.Y
 	for i := 0; i < len(value); i++ {
-		if value[i] == '\n' {
+		if value[i] == '\n' || (value[i] == '\r' && i < len(value)-1 && value[i+1] == '\n') {
 			la.split(Loc{x, y})
 			x = 0
 			y++
+
+			if value[i] == '\r' {
+				i++
+			}
+
 			continue
 		}
 		la.insertByte(Loc{x, y}, value[i])
