@@ -16,8 +16,8 @@ import (
 	"github.com/blang/semver"
 	lua "github.com/yuin/gopher-lua"
 	"github.com/zyedidia/json5"
-	ulua "github.com/zyedidia/micro/internal/lua"
-	"github.com/zyedidia/micro/internal/util"
+	ulua "github.com/zyedidia/micro/v2/internal/lua"
+	"github.com/zyedidia/micro/v2/internal/util"
 )
 
 var (
