@@ -1,14 +1,12 @@
 package display
 
 import (
-	"unicode/utf8"
-
 	runewidth "github.com/mattn/go-runewidth"
-	"github.com/zyedidia/micro/internal/buffer"
-	"github.com/zyedidia/micro/internal/config"
-	"github.com/zyedidia/micro/internal/info"
-	"github.com/zyedidia/micro/internal/screen"
-	"github.com/zyedidia/micro/internal/util"
+	"github.com/zyedidia/micro/v2/internal/buffer"
+	"github.com/zyedidia/micro/v2/internal/config"
+	"github.com/zyedidia/micro/v2/internal/info"
+	"github.com/zyedidia/micro/v2/internal/screen"
+	"github.com/zyedidia/micro/v2/internal/util"
 	"github.com/zyedidia/tcell"
 )
 
@@ -70,7 +68,7 @@ func (i *InfoWindow) IsActive() bool   { return true }
 func (i *InfoWindow) LocFromVisual(vloc buffer.Loc) buffer.Loc {
 	c := i.Buffer.GetActiveCursor()
 	l := i.Buffer.LineBytes(0)
-	n := utf8.RuneCountInString(i.Msg)
+	n := util.CharacterCountInString(i.Msg)
 	return buffer.Loc{c.GetCharPosInLine(l, vloc.X-n), 0}
 }
 
@@ -86,13 +84,13 @@ func (i *InfoWindow) displayBuffer() {
 	activeC := b.GetActiveCursor()
 
 	blocX := 0
-	vlocX := utf8.RuneCountInString(i.Msg)
+	vlocX := util.CharacterCountInString(i.Msg)
 
 	tabsize := 4
 	line, nColsBeforeStart, bslice := util.SliceVisualEnd(line, blocX, tabsize)
 	blocX = bslice
 
-	draw := func(r rune, style tcell.Style) {
+	draw := func(r rune, combc []rune, style tcell.Style) {
 		if nColsBeforeStart <= 0 {
 			bloc := buffer.Loc{X: blocX, Y: 0}
 			if activeC.HasSelection() &&
@@ -112,8 +110,9 @@ func (i *InfoWindow) displayBuffer() {
 				c := r
 				if j > 0 {
 					c = ' '
+					combc = nil
 				}
-				screen.SetContent(vlocX, i.Y, c, nil, style)
+				screen.SetContent(vlocX, i.Y, c, combc, style)
 			}
 			vlocX++
 		}
@@ -124,9 +123,9 @@ func (i *InfoWindow) displayBuffer() {
 	for len(line) > 0 {
 		curVX := vlocX
 		curBX := blocX
-		r, size := utf8.DecodeRune(line)
+		r, combc, size := util.DecodeCharacter(line)
 
-		draw(r, i.defStyle())
+		draw(r, combc, i.defStyle())
 
 		width := 0
 
@@ -146,7 +145,7 @@ func (i *InfoWindow) displayBuffer() {
 		// Draw any extra characters either spaces for tabs or @ for incomplete wide runes
 		if width > 1 {
 			for j := 1; j < width; j++ {
-				draw(char, i.defStyle())
+				draw(char, nil, i.defStyle())
 			}
 		}
 		if activeC.X == curBX {
@@ -191,7 +190,7 @@ func (i *InfoWindow) scrollToSuggestion() {
 	s := i.totalSize()
 
 	for j, n := range i.Suggestions {
-		c := utf8.RuneCountInString(n)
+		c := util.CharacterCountInString(n)
 		if j == i.CurSuggestion {
 			if x+c >= i.hscroll+i.Width {
 				i.hscroll = util.Clamp(x+c+1-i.Width, 0, s-i.Width)
